package com.inspur.mapper;

import java.util.List;
import com.inspur.domain.ElevatorInfo;

/**
 * 电梯信息Mapper接口
 *
 * @author inspur
 * @date 2024-10-08
 */
public interface ElevatorInfoMapper
{
    /**
     * 查询电梯信息
     *
     * @param id 电梯信息主键
     * @return 电梯信息
     */
    public ElevatorInfo selectElevatorInfoById(Long id);

    /**
     * 查询电梯信息列表
     *
     * @param elevatorInfo 电梯信息
     * @return 电梯信息集合
     */
    public List<ElevatorInfo> selectElevatorInfoList(ElevatorInfo elevatorInfo);

    /**
     * 新增电梯信息
     *
     * @param elevatorInfo 电梯信息
     * @return 结果
     */
    public int insertElevatorInfo(ElevatorInfo elevatorInfo);

    /**
     * 修改电梯信息
     *
     * @param elevatorInfo 电梯信息
     * @return 结果
     */
    public int updateElevatorInfo(ElevatorInfo elevatorInfo);

    /**
     * 删除电梯信息
     *
     * @param id 电梯信息主键
     * @return 结果
     */
    public int deleteElevatorInfoById(Long id);

    /**
     * 批量删除电梯信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElevatorInfoByIds(Long[] ids);

    /**
     * 根据安全码查询电梯信息
     * @param dtmf
     * @return
     */
    public ElevatorInfo selectElevatorInfoBySafeCode(String dtmf);
}
